PyG2
========

A grammar of graphics python library for jupyter notebooks on top of G2

Author
========
Thamalu Maliththa Piyadigama

Based on 
==========

AntV/G2 javascript library

Description
=============

A python wrapped version of G2 charting library. Works on **Jupyter notebooks**. Provide Grammar of Graphics support to jupyter notebooks. 

Syntax is closer to original G2.  

What is new!
=============
+ Support for configuration of guides, legends, interaction and other graph elements. 
+ Offline chart generation

Future developments
=======================


+ Add support to colab and other IPython environments
+ Add support to different rendering methods
+ Provide javascript code snippets to embed graphs into web pages.

